import pandas as pd
import os
import pyBigWig

infile = "~/ChIP_atlas/resources/experimentList_mm10_TFs_only_QC_filtered.tab"
Chip = pd.read_csv(infile,sep='\t',index_col=0,usecols=(0,3))

# sort by tf name
Chip = Chip.sort_values('antigen',axis=0)
# take a small subset for testing
#Chip = Chip.loc[ (Chip.tf=='Clock') | (Chip.tf=='Arntl'), :]

outfile='mm10/trackDb.txt'
with open(outfile,'w', encoding="utf-8") as fout:
    for tf in Chip.antigen.unique():
        print(tf)

        # BigWig tracks

        fout.write(f"track ChIP_{tf}\n")
        fout.write("type bigWig\n")
        fout.write("container multiWig\n")
        fout.write(f"shortLabel {tf}\n")
        fout.write(f"longLabel ChIP-seq {tf}\n")
        fout.write("visibility hide\n")
        fout.write("aggregate transparentOverlay\n")
        fout.write("showSubtrackColorOnUi on\n")
        fout.write("maxHeightPixels 500:100:8\n")
        fout.write("autoScale on\n")
        fout.write("\n")

        i = 0

        n = sum(Chip.antigen==tf)
        G = min(n+159,240)
        for idx in Chip.loc[Chip.antigen==tf].index:
            if os.path.exists(f'tracks/mm10/{idx}.bw'):
                try:
                    pyBigWig.open(f'tracks/mm10/{idx}.bw')
                except:
                    print('file corrupted')
                finally:
                    i+=1

                    fout.write(f"\ttrack ChIP_{tf}_{i}\n")
                    fout.write(f"\tbigDataUrl http://upnaesrv1.epfl.ch/ChIP_Atlas/tracks/mm10/{idx}.bw\n")
                    fout.write(f"\tshortLabel {tf}_{i}\n")
                    fout.write(f"\tlongLabel Chip_{tf}_{i}\n")
                    fout.write(f"\tparent ChIP_{tf}\n")
                    fout.write("\ttype bigWig\n")
                    fout.write(f"\tcolor 255,{G},255\n")
                    fout.write("\n")

        fout.write("###################\n\n")
